@@ -27,6 +27,7 @@ from concurrent.futures import Future, ThreadPoolExecutor
 from functools import partial, update_wrapper
 from http.client import InvalidURL
 from itertools import count
+from json import dumps
 from os import fsencode, PathLike
 from posixpath import join as joinpath, split as splitpath, splitext
 from stat import S_IFDIR, S_IFREG
@@ -237,9 +238,13 @@ class AlistFuseOperations(Operations):
         attr = self.getattr(path)
         pathobj = attr["_path"]
         match name:
+            case "attr":
+                return fsencode(dumps(pathobj.client.attr(pathobj)))
             case "sign" | "thumb" | "type" | "hashinfo":
                 return fsencode(str(pathobj[name]))
             case "url":
+                if pathobj.is_dir():
+                    raise IsADirectoryError(errno.EISDIR, pathobj)
                 return fsencode(pathobj.get_url())
             case _:
                 raise OSError(errno.ENOATTR, name)
@@ -247,7 +252,7 @@ class AlistFuseOperations(Operations):
     def listxattr(self, /, path: str):
         if path == "/":
             return ()
-        return ("sign", "thumb", "type", "hashinfo", "url")
+        return ("attr", "sign", "thumb", "type", "hashinfo", "url")
 
     def open(self, /, path: str, flags: int = 0) -> int:
         self._log(logging.INFO, "open(path=\x1b[4;34m%r\x1b[0m, flags=%r) by \x1b[3;4m%s\x1b[0m", path, flags, PROCESS_STR)
